@@ -8,7 +8,7 @@ package Business::Tax::VAT::Validation;
  ############################################################################
 # Original author:                                                           #
 # IT Development software                                                    #
-# European VAT number validator Version 1.0.2                                #
+# European VAT number validator                                              #
 # Created 06/08/2003                                                         #
 #                                                                            #
 # Maintainership kindly handed over to David Precious (BIGPRESH) in 2015     #
@@ -29,7 +29,7 @@ package Business::Tax::VAT::Validation;
 use strict;
 use warnings;
 
-our $VERSION = '1.22';
+our $VERSION = '1.23';
 
 use HTTP::Request::Common qw(POST);
 use LWP::UserAgent;
@@ -55,7 +55,7 @@ Business::Tax::VAT::Validation - Validate EU VAT numbers against VIES/HMRC
 =head1 DESCRIPTION
 
 This class provides an easy API to check European VAT numbers' syntax,
-and if they has been registered by the competent authorities.
+and check if they have been registered by the competent authorities.
 
 It asks the EU database (VIES) for this, using its SOAP API.  Basic checks that
 the supplied VAT number fit the expected format for the specified EU member
@@ -74,11 +74,11 @@ REST API provided by their HMRC.
     $hvatn=Business::Tax::VAT::Validation->new();
 
 
-    If your system is located behind a proxy :
+    # If your system is located behind a proxy :
 
     $hvatn=Business::Tax::VAT::Validation->new(-proxy => ['http', 'http://example.com:8001/']);
 
-    Note : See LWP::UserAgent for proxy options.
+    # Note : See LWP::UserAgent for proxy options.
 
 =cut
 
@@ -279,7 +279,7 @@ Possible errors are :
 =over 4
 
 =item *
- -1  The provided VAT number is valid.
+ -1  The provided VAT number is valid (so, no error occurred)
 
 =item *
   0  Unknown MS code : Internal checkup failed (Specified Member State does not exist)
@@ -440,10 +440,10 @@ sub _is_res_ok {
         if ($res=~m/<ns2:valid> *(.*?) *<\/ns2:valid>/) {
             my $v = $1;
             if ($v eq 'true' || $v eq '1') {
-                if ($res=~m/<name> *(.*?) *<\/name>/) {
+                if ($res=~m/<ns2:name> *(.*?) *<\/ns2:name>/) {
                     $self->{information}{name} = $1
                 }
-                if ($res=~m/<address> *(.*?) *<\/address>/) {
+                if ($res=~m/<ns2:address> *(.*?) *<\/ns2:address>/) {
                     $self->{information}{address} = $1
                 }
                 $self->_set_error( -1, 'Valid VAT Number');
